@@ -12,3 +12,7 @@ BATCHGLM_OPTIM_IRLS_GD_TR = True
 BATCHGLM_PROVIDE_BATCHED = True
 BATCHGLM_PROVIDE_FIM = True
 BATCHGLM_PROVIDE_HESSIAN = False
+
+BATCHGLM_BACKEND = "tf1"
+BATCHGLM_FEATUREWISE = True
+BATCHGLM_AUTOGRAD = True
