@@ -52,19 +52,20 @@ def parse_sample_description(
                 "with corresponding sample annotations"
             )
 
-    if anndata is not None and isinstance(data, Raw):
-        # Raw does not have attribute shape.
-        assert data.X.shape[0] == sample_description.shape[0], \
-            "data matrix and sample description must contain same number of cells: %i, %i" % \
-            (data.X.shape[0], sample_description.shape[0])
-    elif isinstance(data, glm.typing.InputDataBase):
-        assert data.x.shape[0] == sample_description.shape[0], \
-            "data matrix and sample description must contain same number of cells: %i, %i" % \
-            (data.x.shape[0], sample_description.shape[0])
-    else:
-        assert data.shape[0] == sample_description.shape[0], \
-            "data matrix and sample description must contain same number of cells: %i, %i" % \
-            (data.shape[0], sample_description.shape[0])
+    if sample_description is not None:
+        if anndata is not None and isinstance(data, Raw):
+            # Raw does not have attribute shape.
+            assert data.X.shape[0] == sample_description.shape[0], \
+                "data matrix and sample description must contain same number of cells: %i, %i" % \
+                (data.X.shape[0], sample_description.shape[0])
+        elif isinstance(data, glm.typing.InputDataBase):
+            assert data.x.shape[0] == sample_description.shape[0], \
+                "data matrix and sample description must contain same number of cells: %i, %i" % \
+                (data.x.shape[0], sample_description.shape[0])
+        else:
+            assert data.shape[0] == sample_description.shape[0], \
+                "data matrix and sample description must contain same number of cells: %i, %i" % \
+                (data.shape[0], sample_description.shape[0])
     return sample_description
 
 
@@ -89,7 +90,14 @@ def parse_size_factors(
         elif isinstance(size_factors, str):
             assert size_factors in sample_description.columns, ""
             size_factors = sample_description[size_factors].values
-        assert size_factors.shape[0] == data.shape[0], "data matrix and size factors must contain same number of cells"
+
+        if anndata is not None and isinstance(data, Raw):
+            data_shape = data.X.shape
+        elif isinstance(data, glm.typing.InputDataBase):
+            data_shape = data.x.shape
+        else:
+            data_shape = data.shape
+        assert size_factors.shape[0] == data_shape[0], "data matrix and size factors must contain same number of cells"
         assert np.all(size_factors > 0), "size_factors <= 0 found, please remove these cells"
     return size_factors
 
@@ -117,8 +125,7 @@ def dmat_unique(dmat, sample_description):
 
 
 def design_matrix(
-        data: Union[anndata.AnnData, Raw, np.ndarray,
-                    scipy.sparse.csr_matrix] = None,
+        data: Union[anndata.AnnData, Raw, np.ndarray, scipy.sparse.csr_matrix] = None,
         sample_description: Union[None, pd.DataFrame] = None,
         formula: Union[None, str] = None,
         as_numeric: Union[List[str], Tuple[str], str] = (),
@@ -206,7 +213,7 @@ def preview_coef_names(
 
 
 def constraint_system_from_star(
-        dmat: Union[None, np.ndarray] = None,
+        dmat: Union[None, patsy.design_info.DesignMatrix] = None,
         sample_description: Union[None, pd.DataFrame] = None,
         formula: Union[None, str] = None,
         as_numeric: Union[List[str], Tuple[str], str] = (),
@@ -264,3 +271,49 @@ def constraint_system_from_star(
         constraints=constraints,
         return_type=return_type
     )
+
+
+def bin_continuous_covariate(
+        factor_to_bin: str,
+        bins: Union[int, list, np.ndarray, Tuple],
+        data: Union[None, anndata.AnnData] = None,
+        sample_description: Union[None, pd.DataFrame] = None
+):
+    r"""
+    Bin a continuous covariate.
+
+    Adds the binned covariate to the table. If data is supplied, the covariate is added in place in data.obs, otherwise
+    the covariate is added in the sample_description and the new sample_description is returned.
+     Binning is performed on quantiles of the distribution.
+
+    :param factor_to_bin: Name of columns of factor to bin.
+    :param bins: Number of bins or iteratable with bin borders. If given as integer, the bins are defined on the
+        quantiles of the covariate, ie the bottom 20% of observations are in the first bin if bins==5.
+    :param data: Anndata object that contains sample description table in .obs.
+    :param sample_description: Sample description table.
+    :return: Sample description table with binned covariate added if sample_description was supplied, otherwise None is
+        returned as the new column was added in place.
+    """
+    if data is None and sample_description is not None:
+        sd = sample_description
+    elif data is not None and sample_description is None:
+        sd = data.obs
+    else:
+        raise ValueError("supply either data or sample_description")
+    if isinstance(bins, list) or isinstance(bins, np.ndarray) or isinstance(bins, Tuple):
+        bins = np.asarray(bins)
+    else:
+        bins = np.arange(0, 1, 1 / bins)
+
+    fac_binned = glm.data.bin_continuous_covariate(
+        sample_description=sd,
+        factor_to_bin=factor_to_bin,
+        bins=bins
+    )
+    if data is None and sample_description is not None:
+        sd[factor_to_bin + "_binned"] = fac_binned
+        return sample_description
+    elif data is not None and sample_description is None:
+        data.obs[factor_to_bin + "_binned"] = fac_binned
+    else:
+        assert False
