@@ -3,7 +3,7 @@ import unittest
 import numpy as np
 import logging
 
-from batchglm.api.models.glm_nb import Simulator
+from batchglm.api.models.numpy.glm_nb import Simulator
 import diffxpy.api as de
 
 
