@@ -22,7 +22,7 @@ class TestVsRest(unittest.TestCase):
         logging.getLogger("tensorflow").setLevel(logging.ERROR)
         logging.getLogger("batchglm").setLevel(logging.WARNING)
         logging.getLogger("diffxpy").setLevel(logging.WARNING)
-        from batchglm.api.models.glm_nb import Simulator
+        from batchglm.api.models.numpy.glm_nb import Simulator
 
         sim = Simulator(num_observations=n_cells, num_features=n_genes)
         sim.generate_sample_description(num_batches=0, num_conditions=0)
@@ -33,7 +33,7 @@ class TestVsRest(unittest.TestCase):
         })
 
         test = de.test.versus_rest(
-            data=sim.x,
+            data=sim.input_data,
             grouping="condition",
             test="wald",
             noise_model="nb",
@@ -65,7 +65,7 @@ class TestVsRest(unittest.TestCase):
         logging.getLogger("tensorflow").setLevel(logging.ERROR)
         logging.getLogger("batchglm").setLevel(logging.WARNING)
         logging.getLogger("diffxpy").setLevel(logging.ERROR)
-        from batchglm.api.models.glm_nb import Simulator
+        from batchglm.api.models.numpy.glm_nb import Simulator
 
         sim = Simulator(num_observations=n_cells, num_features=n_genes)
         sim.generate_sample_description(num_batches=0, num_conditions=0)
@@ -76,7 +76,7 @@ class TestVsRest(unittest.TestCase):
         })
 
         test = de.test.versus_rest(
-            data=sim.x,
+            data=sim.input_data,
             grouping="condition",
             test="lrt",
             noise_model="nb",
@@ -108,7 +108,7 @@ class TestVsRest(unittest.TestCase):
         logging.getLogger("tensorflow").setLevel(logging.ERROR)
         logging.getLogger("batchglm").setLevel(logging.WARNING)
         logging.getLogger("diffxpy").setLevel(logging.WARNING)
-        from batchglm.api.models.glm_nb import Simulator
+        from batchglm.api.models.numpy.glm_nb import Simulator
 
         sim = Simulator(num_observations=n_cells, num_features=n_genes)
         sim.generate_sample_description(num_batches=0, num_conditions=0)
@@ -119,7 +119,7 @@ class TestVsRest(unittest.TestCase):
         })
 
         test = de.test.versus_rest(
-            data=sim.x,
+            data=sim.input_data,
             grouping="condition",
             test="rank",
             sample_description=random_sample_description,
@@ -148,7 +148,7 @@ class TestVsRest(unittest.TestCase):
         logging.getLogger("tensorflow").setLevel(logging.ERROR)
         logging.getLogger("batchglm").setLevel(logging.WARNING)
         logging.getLogger("diffxpy").setLevel(logging.WARNING)
-        from batchglm.api.models.glm_norm import Simulator
+        from batchglm.api.models.numpy.glm_norm import Simulator
 
         sim = Simulator(num_observations=n_cells, num_features=n_genes)
         sim.generate_sample_description(num_batches=0, num_conditions=0)
@@ -159,7 +159,7 @@ class TestVsRest(unittest.TestCase):
         })
 
         test = de.test.versus_rest(
-            data=sim.x,
+            data=sim.input_data,
             grouping="condition",
             test="t-test",
             sample_description=random_sample_description,
